@@ -12,7 +12,7 @@ from tornado.httpclient import AsyncHTTPClient, HTTPError, HTTPRequest
 from tornado.httputil import url_concat
 
 from qctic.schemas import BackendStatusSchema, GetJobsQuerySchema, JobSchema
-from qctic.utils import qasm_qobj_to_dict
+from qctic.utils import ensure_serializable_dict, qasm_qobj_to_dict
 
 _SCHEME_REGEX = r"^.+://.*"
 _SCHEME_DEFAULT = "http"
@@ -265,7 +265,8 @@ class QCticAPI:
         }
 
         if job.run_params and len(job.run_params) > 0:
-            job_init.update({"run_params": job.run_params})
+            run_params = ensure_serializable_dict(job.run_params)
+            job_init.update({"run_params": run_params})
 
         body = json_encode(JobSchema().dump(job_init))
 
