@@ -76,3 +76,15 @@ class QobjEncoder(json.JSONEncoder):
 
 def qasm_qobj_to_dict(qobj):
     return json.loads(json.dumps(qobj.to_dict(), cls=QobjEncoder))
+
+
+def ensure_serializable_dict(input_dict):
+    ret = {}
+
+    for key, val in input_dict.items():
+        try:
+            ret[key] = val.to_dict(serializable=True)
+        except:
+            ret[key] = val
+
+    return ret
