@@ -103,6 +103,30 @@ def test_get_jobs_arg_status(httpserver):
     assert all(item["status"] in status_list for item in res)
 
 
+def test_get_jobs_arg_lean_truthy(httpserver):
+    job_dicts = [fake_job_dict() for _ in range(5)]
+
+    def handler(req):
+        assert req.args.get("lean")
+        return Response(json.dumps([item for item in job_dicts]))
+
+    httpserver.expect_request("/jobs").respond_with_handler(handler)
+    api = _build_api(httpserver)
+    assert api.get_jobs_sync(lean=True)
+
+
+def test_get_jobs_arg_lean_falsy(httpserver):
+    job_dicts = [fake_job_dict() for _ in range(5)]
+
+    def handler(req):
+        assert req.args.get("lean", None) is None
+        return Response(json.dumps([item for item in job_dicts]))
+
+    httpserver.expect_request("/jobs").respond_with_handler(handler)
+    api = _build_api(httpserver)
+    assert api.get_jobs_sync(lean=False)
+
+
 def test_get_backend_status(httpserver):
     httpserver.expect_request("/status").respond_with_json({
         "operational": True,
